diff --git a/.github/workflows/ci.yml b/.github/workflows/ci.yml
index b44c909..3fb9eb0 100644
--- a/.github/workflows/ci.yml
+++ b/.github/workflows/ci.yml
@@ -33,6 +33,10 @@ jobs:
with:
ruby-version: '2.5'
+ - uses: actions/setup-python@v2
+ with:
+ python-version: '3.8'
+
- name: Configure Jekyll
if: matrix.jekyll-versions != '(GitHub Pages)'
run: |
diff --git a/README.md b/README.md
index e76c4bb..bf4677b 100644
--- a/README.md
+++ b/README.md
@@ -58,12 +58,17 @@ This snippet is highly customizable. Here are the available parameters to change
| `ordered` | bool | false | when set to true, an ordered list will be outputted instead of an unordered list |
| `item_class` | string | '' | add custom class for each list item; has support for `%level%` placeholder, which is the current heading level |
| `submenu_class` | string | '' | add custom class(es) for each child group of headings; has support for `%level%` placeholder which is the current "submenu" heading level |
-| `baseurl` | string | '' | add a base url to the TOC links for when your TOC is on another page than the actual content |
+| `base_url` | string | '' | add a base url to the TOC links for when your TOC is on another page than the actual content |
| `anchor_class` | string | '' | add custom class(es) for each anchor element |
-| `skipNoIDs` | bool | false | skip headers that do not have an `id` attribute |
+| `skip_no_ids` | bool | false | skip headers that do not have an `id` attribute |
* This is a required parameter
+### Deprecated Variables
+
+- `baseurl` has been deprecated since 1.1.0, use `base_url` instead
+- `skipNoIDs` has been deprecated since 1.1.0, use `skip_no_ids` instead
+
## Performance
The performance impact of this snippet on your site is pretty negligible. The stats below were gotten from Jekyll's `--profile` option.
diff --git a/_includes/toc.html b/_includes/toc.html
index e6c1cb4..8c71007 100644
--- a/_includes/toc.html
+++ b/_includes/toc.html
@@ -24,7 +24,7 @@
OTHER DEALINGS IN THE SOFTWARE.
{% endcomment %}
{% comment %}
- Version 1.0.14
+ Version 1.1.0
https://github.com/allejo/jekyll-toc
"...like all things liquid - where there's a will, and ~36 hours to spare, there's usually a/some way" ~jaybe
@@ -44,34 +44,51 @@
* ordered (bool) : false - when set to true, an ordered list will be outputted instead of an unordered list
* item_class (string) : '' - add custom class(es) for each list item; has support for '%level%' placeholder, which is the current heading level
* submenu_class (string) : '' - add custom class(es) for each child group of headings; has support for '%level%' placeholder which is the current "submenu" heading level
- * baseurl (string) : '' - add a base url to the TOC links for when your TOC is on another page than the actual content
+ * base_url (string) : '' - add a base url to the TOC links for when your TOC is on another page than the actual content
* anchor_class (string) : '' - add custom class(es) for each anchor element
- * skipNoIDs (bool) : false - skip headers that do not have an `id` attribute
+ * skip_no_ids (bool) : false - skip headers that do not have an `id` attribute
Output:
An ordered or unordered list representing the table of contents of a markdown block. This snippet will only
generate the table of contents and will NOT output the markdown given to it
{% endcomment %}
- {% capture my_toc %}{% endcapture %}
+ {% capture newline %}
+ {% endcapture %}
+ {% assign newline = newline | rstrip %}
+
+ {% capture deprecation_warnings %}{% endcapture %}
+
+ {% if include.baseurl %}
+ {% capture deprecation_warnings %}{{ deprecation_warnings }}{{ newline }}{% endcapture %}
+ {% endif %}
+
+ {% if include.skipNoIDs %}
+ {% capture deprecation_warnings %}{{ deprecation_warnings }}{{ newline }}{% endcapture %}
+ {% endif %}
+
+ {% capture jekyll_toc %}{% endcapture %}
{% assign orderedList = include.ordered | default: false %}
- {% assign skipNoIDs = include.skipNoIDs | default: false %}
+ {% assign baseURL = include.base_url | default: include.baseurl | default: '' %}
+ {% assign skipNoIDs = include.skip_no_ids | default: include.skipNoIDs | default: false %}
{% assign minHeader = include.h_min | default: 1 %}
{% assign maxHeader = include.h_max | default: 6 %}
- {% assign nodes = include.html | split: ' maxHeader %}
+ {% if currLevel < minHeader or currLevel > maxHeader %}
{% continue %}
{% endif %}
@@ -79,92 +96,87 @@
{% assign _idWorkspace = _workspace[0] | split: 'id="' %}
{% assign _idWorkspace = _idWorkspace[1] | split: '"' %}
- {% assign html_id = _idWorkspace[0] %}
+ {% assign htmlID = _idWorkspace[0] %}
{% assign _classWorkspace = _workspace[0] | split: 'class="' %}
{% assign _classWorkspace = _classWorkspace[1] | split: '"' %}
- {% assign html_class = _classWorkspace[0] %}
+ {% assign htmlClass = _classWorkspace[0] %}
- {% if html_class contains "no_toc" %}
+ {% if htmlClass contains "no_toc" %}
{% continue %}
{% endif %}
{% if firstHeader %}
- {% assign firstHeader = false %}
- {% assign minHeader = headerLevel %}
+ {% assign minHeader = currLevel %}
{% endif %}
{% capture _hAttrToStrip %}{{ _workspace[0] | split: '>' | first }}>{% endcapture %}
{% assign header = _workspace[0] | replace: _hAttrToStrip, '' %}
- {% assign indentAmount = headerLevel | minus: minHeader %}
- {% assign space = '' %}
- {% for i in (1..indentAmount) %}
- {% assign space = space | prepend: ' ' %}
- {% endfor %}
-
{% if include.item_class and include.item_class != blank %}
- {% capture listItemClass %}{:.{{ include.item_class | replace: '%level%', headerLevel }}}{% endcapture %}
+ {% capture listItemClass %} class="{{ include.item_class | replace: '%level%', currLevel | split: '.' | join: ' ' }}"{% endcapture %}
+ {% endif %}
+
+ {% if include.submenu_class and include.submenu_class != blank %}
+ {% assign subMenuLevel = currLevel | minus: 1 %}
+ {% capture subMenuClass %} class="{{ include.submenu_class | replace: '%level%', subMenuLevel | split: '.' | join: ' ' }}"{% endcapture %}
{% endif %}
- {% capture anchor_body %}{% if include.sanitize %}{{ header | strip_html }}{% else %}{{ header }}{% endif %}{% endcapture %}
- {% capture anchor_body %}{{ anchor_body | replace: "|", "\|" }}{% endcapture %}
+ {% capture anchorBody %}{% if include.sanitize %}{{ header | strip_html }}{% else %}{{ header }}{% endif %}{% endcapture %}
+
+ {% if htmlID %}
+ {% capture anchorAttributes %} href="{% if baseURL %}{{ baseURL }}{% endif %}#{{ htmlID }}"{% endcapture %}
+
+ {% if include.anchor_class %}
+ {% capture anchorAttributes %}{{ anchorAttributes }} class="{{ include.anchor_class | split: '.' | join: ' ' }}"{% endcapture %}
+ {% endif %}
- {% if html_id %}
- {% capture list_item %}[{{ anchor_body }}]({% if include.baseurl %}{{ include.baseurl }}{% endif %}#{{ html_id }}){% endcapture %}
+ {% capture listItem %}{{ anchorBody }}{% endcapture %}
{% elsif skipNoIDs == true %}
{% continue %}
{% else %}
- {% capture list_item %}{{ anchor_body }}{% endcapture %}
+ {% capture listItem %}{{ anchorBody }}{% endcapture %}
{% endif %}
-
- {% if include.submenu_class and previousLevel > indentAmount %}
-
- {% assign submenuIndentation = space | prepend: ' ' %}
-
- {% capture my_toc %}{{ my_toc }}
-{{ submenuIndentation }}{:.{{ include.submenu_class | replace: '%level%', previousLevel }}}{% endcapture %}
+ {% if currLevel > lastLevel %}
+ {% capture jekyll_toc %}{{ jekyll_toc }}<{{ listModifier }}{{ subMenuClass }}>{% endcapture %}
+ {% elsif currLevel < lastLevel %}
+ {% assign repeatCount = lastLevel | minus: currLevel %}
+
+ {% for i in (1..repeatCount) %}
+ {% capture jekyll_toc %}{{ jekyll_toc }}{{ listModifier }}>{% endcapture %}
+ {% endfor %}
+
+ {% capture jekyll_toc %}{{ jekyll_toc }}{% endcapture %}
+ {% else %}
+ {% capture jekyll_toc %}{{ jekyll_toc }}{% endcapture %}
{% endif %}
- {% capture my_toc %}{{ my_toc }}
-{{ space }}{{ listModifier }} {{ listItemClass }} {{ list_item }}{% if include.anchor_class %}{:.{{ include.anchor_class }}}{% endif %}{% endcapture %}
+ {% capture jekyll_toc %}{{ jekyll_toc }}{{ listItem }}{% endcapture %}
- {% assign previousLevel = indentAmount %}
+ {% assign lastLevel = currLevel %}
+ {% assign firstHeader = false %}
{% endfor %}
- {% if include.class and include.class != blank %}
- {% capture my_toc %}{:.{{ include.class }}}
-{{ my_toc | lstrip }}{% endcapture %}
- {% endif %}
+ {% assign repeatCount = minHeader | minus: 1 %}
+ {% assign repeatCount = lastLevel | minus: repeatCount %}
+ {% for i in (1..repeatCount) %}
+ {% capture jekyll_toc %}{{ jekyll_toc }}{{ listModifier }}>{% endcapture %}
+ {% endfor %}
- {% if include.id %}
- {% capture my_toc %}{: #{{ include.id }}}
-{{ my_toc | lstrip }}{% endcapture %}
- {% endif %}
+ {% if jekyll_toc != '' %}
+ {% assign rootAttributes = '' %}
+ {% if include.class and include.class != blank %}
+ {% capture rootAttributes %} class="{{ include.class | split: '.' | join: ' ' }}"{% endcapture %}
+ {% endif %}
-
- {% if include.submenu_class != blank %}
-
- {% for i in (1..previousLevel) %}
- {% assign lvl = previousLevel | plus: 1 | minus: i %}
- {% assign closingSpace = '' %}
-
- {% for i in (1..lvl) %}
- {% assign closingSpace = closingSpace | prepend: ' ' %}
- {% endfor %}
+ {% if include.id and include.id != blank %}
+ {% capture rootAttributes %}{{ rootAttributes }} id="{{ include.id }}"{% endcapture %}
+ {% endif %}
- {% capture my_toc %}{{ my_toc }}
-{{ closingSpace }}{:.{{ include.submenu_class | replace: '%level%', lvl }}}{% endcapture %}
- {% endfor %}
+ {% if rootAttributes %}
+ {% assign nodes = jekyll_toc | split: '>' %}
+ {% capture jekyll_toc %}<{{ listModifier }}{{ rootAttributes }}>{{ nodes | shift | join: '>' }}>{% endcapture %}
+ {% endif %}
{% endif %}
-{% endcapture %}{% assign tocWorkspace = '' %}{{ my_toc | markdownify | strip }}
+{% endcapture %}{% assign tocWorkspace = '' %}{{ deprecation_warnings }}{{ jekyll_toc }}
diff --git a/_tests/base_url-deprecated.md b/_tests/base_url-deprecated.md
new file mode 100644
index 0000000..40ec785
--- /dev/null
+++ b/_tests/base_url-deprecated.md
@@ -0,0 +1,15 @@
+---
+---
+
+{% capture markdown %}
+# Heading 1
+{% endcapture %}
+{% assign text = markdown | markdownify %}
+
+{% include toc.html html=text baseurl="example.org" %}
+
+
+
+
diff --git a/_tests/base_url.md b/_tests/base_url.md
index 40ec785..282f376 100644
--- a/_tests/base_url.md
+++ b/_tests/base_url.md
@@ -6,7 +6,7 @@
{% endcapture %}
{% assign text = markdown | markdownify %}
-{% include toc.html html=text baseurl="example.org" %}
+{% include toc.html html=text base_url="example.org" %}
diff --git a/_tests/skipHeadingsWithNoIDs-Deprecated.md b/_tests/skipHeadingsWithNoIDs-Deprecated.md
new file mode 100644
index 0000000..e90cd7f
--- /dev/null
+++ b/_tests/skipHeadingsWithNoIDs-Deprecated.md
@@ -0,0 +1,50 @@
+---
+# https://github.com/allejo/jekyll-toc/issues/32
+---
+
+{% capture markdown %}
+## Sample Usage
+
+
+
My Awesome Example Page
+
With an awesome subtitle
+
Dummy Link
+
+
+### Known Problems
+
+Lots!
+
+### Resources
+
+#### Paid
+
+#### Free
+{% endcapture %}
+{% assign text = markdown | markdownify %}
+
+{% include toc.html html=text skipNoIDs=true %}
+
+
+
+
diff --git a/_tests/skipHeadingsWithNoIDs.md b/_tests/skipHeadingsWithNoIDs.md
index e90cd7f..52aea43 100644
--- a/_tests/skipHeadingsWithNoIDs.md
+++ b/_tests/skipHeadingsWithNoIDs.md
@@ -23,7 +23,7 @@ Lots!
{% endcapture %}
{% assign text = markdown | markdownify %}
-{% include toc.html html=text skipNoIDs=true %}
+{% include toc.html html=text skip_no_ids=true %}
diff --git a/tests.py b/tests.py
index edbadbe..24787f2 100644
--- a/tests.py
+++ b/tests.py
@@ -3,7 +3,7 @@
import unittest
import xml.etree.ElementTree as ET
-class TestSequense(unittest.TestCase):
+class TestSequence(unittest.TestCase):
pass
def test_generator(a, b):
@@ -11,9 +11,14 @@ def test(self):
self.assertEqual(a, b)
return test
-def normalize_xml(xml):
- tree = ET.fromstring(xml)
- return re.sub('\\n\s+', '', ET.tostring(tree))
+def normalize_xml(xml, test_file):
+ try:
+ tree = ET.fromstring(xml)
+ except:
+ print(f">> Invalid XML in {test_file}")
+ raise
+
+ return re.sub(r'(\\n|\n)\s*', '', str(ET.tostring(tree)), 0, re.MULTILINE)
if __name__ == '__main__':
test_path = os.path.join(os.getcwd(), '_site', 'tests')
@@ -22,12 +27,12 @@ def normalize_xml(xml):
path = os.path.join(test_path, test_file)
with open(path, 'r') as file:
actual, expected = file.read().split('')
- actual = normalize_xml(actual)
- expected = normalize_xml(expected)
+ actual = normalize_xml(actual, test_file)
+ expected = normalize_xml(expected, test_file)
- # Add the unit test to our TestSequense
+ # Add the unit test to our TestSequence
test_name = 'test_{}'.format(test_file)
test = test_generator(actual, expected)
- setattr(TestSequense, test_name, test)
+ setattr(TestSequence, test_name, test)
unittest.main()